@@ -8,7 +8,7 @@
 
 #define G_LOG_DOMAIN "phosh-main"
 
-#include "config.h"
+#include "phosh-config.h"
 
 #include "log.h"
 #include "shell.h"
@@ -87,7 +87,6 @@ on_shell_ready (PhoshShell *shell, GTimer *timer)
 
 int main(int argc, char *argv[])
 {
-  g_autoptr(GSource) sigterm = NULL;
   g_autoptr(GOptionContext) opt_context = NULL;
   GError *err = NULL;
   gboolean unlocked = FALSE, locked = FALSE, version = FALSE;
