@@ -68,8 +68,6 @@ typedef enum {
 } PhoshShellDebugFlags;
 
 
-#define PHOSH_APP_ID "sm.puri.Phosh"
-
 #define PHOSH_TYPE_SHELL phosh_shell_get_type()
 
 
@@ -81,6 +79,7 @@ void                 phosh_shell_get_usable_area (PhoshShell *self,
                                                   int        *y,
                                                   int        *width,
                                                   int        *height);
+void                 phosh_shell_get_area        (PhoshShell *self, int *width, int *height);
 void                 phosh_shell_set_locked      (PhoshShell *self, gboolean locked);
 gboolean             phosh_shell_get_locked      (PhoshShell *self);
 void                 phosh_shell_lock            (PhoshShell *self);
@@ -128,4 +127,5 @@ PhoshShellStateFlags phosh_shell_get_state (PhoshShell *self);
 void                 phosh_shell_set_state (PhoshShell *self, PhoshShellStateFlags state, gboolean enabled);
 PhoshShellDebugFlags phosh_shell_get_debug_flags (PhoshShell *self);
 gboolean             phosh_shell_get_show_splash (PhoshShell *self);
+gboolean             phosh_shell_get_docked      (PhoshShell *self);
 G_END_DECLS
