@@ -6,7 +6,7 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
-#include "config.h"
+#include "phosh-config.h"
 #include "phosh-screenshot-dbus.h"
 #include "portal-dbus.h"
 #include "shell.h"
@@ -90,6 +90,7 @@ wait_a_bit (GMainLoop *loop, int secs)
 }
 
 
+#ifdef HAVE_THUMBNAILS
 static void
 toggle_overview (GMainLoop                      *loop,
                  struct zwp_virtual_keyboard_v1 *keyboard,
@@ -101,6 +102,7 @@ toggle_overview (GMainLoop                      *loop,
   /* Give animation time to finish */
   wait_a_bit (loop, 1);
 }
+#endif
 
 
 static void
@@ -168,8 +170,10 @@ test_take_screenshots (PhoshTestFullShellFixture *fixture, gconstpointer unused)
   g_autoptr (PhoshDBusImplPortalAccess) portal_access_proxy = NULL;
   g_autoptr (GVariant) options = NULL;
   g_autoptr (GError) err = NULL;
+#ifdef HAVE_THUMBNAILS
   const char *argv[] = { TEST_TOOLS "/app-buttons", NULL };
   GPid pid;
+#endif
   gboolean success = FALSE;
   int i = 1;
 
@@ -195,6 +199,7 @@ test_take_screenshots (PhoshTestFullShellFixture *fixture, gconstpointer unused)
   wait_a_bit (loop, 1);
   take_screenshot (locale, i++, "search");
 
+#ifdef HAVE_THUMBNAILS
   g_spawn_async (NULL, (char**) argv, NULL, G_SPAWN_DEFAULT, NULL, NULL, &pid, &err);
   g_assert_no_error (err);
   g_assert_true (pid);
@@ -206,6 +211,7 @@ test_take_screenshots (PhoshTestFullShellFixture *fixture, gconstpointer unused)
   take_screenshot (locale, i++, "overview-app");
   kill (pid, SIGTERM);
   g_spawn_close_pid (pid);
+#endif
 
   toggle_settings (loop, keyboard, timer);
   take_screenshot (locale, i++, "settings");
